# -*- coding: utf-8 -*-
# ############################################################################
# #       ___  ___  __ _                                                     #
# #      / _ \/ __|/ _` |                                                    #
# #     |  __/\__ \ (_| |    Network-of-models                               #
# #      \___/\___/\__,_|                                                    #
# #                                                                          #
# ############################################################################
# The IPR of this software belongs to the European Space Agency. The usage is
# at the discretion of the Agency and licenses for its use should be addressed
# to the Contracts Dept. at ESTEC:
#   European Space Agency ESA/ESTEC
#   Contracts Department
#   Postbus 299
#   2200 AG Noordwijk
#   The Netherlands
#
# For technical issues contact:
#   Developer. Simon Clucas: simon.clucas@esa.int
#
# Release date  : 1 March, 2020
# © Copyright European Space Agency, 2018
#
import os
from os import path
from pathlib import Path
import random

import numpy as np
from nom_client.utils.common_utils import numpy_package

from nom_client.run_context import RunContext
from nom_client.spec_keys import check_dict_keys, NoMKeys

cur_dir = os.path.dirname(os.path.realpath(__file__))
dpath = Path(cur_dir).parent.absolute().parent.absolute()
data_directory = str(os.getenv('NOM_DATA_DIR', path.join(dpath, "data")))


class MyPythonModel:
    """
    MyPythonModel model
    """

    def __init__(self, run_context: RunContext):
        self.run_context = run_context

    def run(self, **kwargs):

        if 'model_inputs' in kwargs:
            model_inputs = kwargs['model_inputs']
        else:
            model_inputs = None

        """
        Get the model inputs supplied by the user/client
        
        The inputs have two input groups:
        
        flux_inputs - single-type user inputs
        function_coeficients - array-type user inputd
        
        """

        if 'flux_inputs' not in model_inputs or 'function_coeficients' not in model_inputs:
            pass

        flux_inputs = model_inputs['flux_inputs']
        energies = flux_inputs['energies']
        flux_scale = flux_inputs['flux_scale']

        function_coeficients = model_inputs['function_coeficients']

        limit = len(energies)
        flux_data = [flux_scale*random.random()*100 for iter in range(limit)]

        return_data = {
            "flux_data": {
                "data": {
                    "energy": [energies],
                    "flux": np.array(flux_data)
                }
            },
            "function_data": {
                "data": {
                    "x": [energies],
                    "y": np.array(flux_data)
                }
            }
        }

        return return_data
